Use the following command to build the UCC UI:
```
npm install && bower install && npm run build
```

Use the following command to build a development package:
```
npm run buildDev
```

The output build is placed in build folder.
